from saenews.utils import quote, put_quote

title = "Is China a Superpower? Is China a Superpower? Is China a Superpower? Is China a Superpower? "
tag_line = "An Analysis by Lt. Gen P R Shankar"

input_file_orig = "China.jpeg"

put_quote(title=title, tag_line=tag_line, black_strip_dims=(0, 0.4, 0, 0.8), input_file_orig=input_file_orig, output_file='', title_cord=(0.0505, 0.700), title_font_size=90, tag_font_size=50, title_width_ratio=1.25, border_width='', logo_border='', border_color='red', title_text_font='', tag_text_font='', tag_width_ratio=0.44, tag_cord=(0.035, 0.866), focus='false', tw_logo='awakenedindian.in',fb_logo='awakenedindian.in', logo=False)


